@@ -306,11 +306,11 @@ KFR_SIMD_TYPE(f64, 2, float64x2_t);
 #define KFR_i8sse_INDEX(x, i) bitcast_anything<simd_array<i8, 16>>(x).val[i]
 #define KFR_i16sse_INDEX(x, i) bitcast_anything<simd_array<i16, 8>>(x).val[i]
 #define KFR_i32sse_INDEX(x, i) _mm_cvtsi128_si32(_mm_shuffle_epi32(x, _MM_SHUFFLE(3, 2, 1, i)))
-#define KFR_i64sse_INDEX(x, i) _mm_cvtsi128_si64(_mm_shuffle_epi32(x, _MM_SHUFFLE(3, 2, (i)*2 + 1, i * 2)))
+#define KFR_i64sse_INDEX(x, i) _mm_cvtsi128_si64(_mm_shuffle_epi32(x, _MM_SHUFFLE(3, 2, (i) * 2 + 1, i * 2)))
 #define KFR_u8sse_INDEX(x, i) bitcast_anything<simd_array<u8, 16>>(x).val[i]
 #define KFR_u16sse_INDEX(x, i) bitcast_anything<simd_array<u16, 8>>(x).val[i]
 #define KFR_u32sse_INDEX(x, i) _mm_cvtsi128_si32(_mm_shuffle_epi32(x, _MM_SHUFFLE(3, 2, 1, i)))
-#define KFR_u64sse_INDEX(x, i) _mm_cvtsi128_si64(_mm_shuffle_epi32(x, _MM_SHUFFLE(3, 2, (i)*2 + 1, i * 2)))
+#define KFR_u64sse_INDEX(x, i) _mm_cvtsi128_si64(_mm_shuffle_epi32(x, _MM_SHUFFLE(3, 2, (i) * 2 + 1, i * 2)))
 #define KFR_f32sse_INDEX(x, i) _mm_cvtss_f32(_mm_shuffle_ps(x, x, _MM_SHUFFLE(3, 2, 1, i)))
 #define KFR_f64sse_INDEX(x, i) _mm_cvtsd_f64(_mm_shuffle_pd(x, x, _MM_SHUFFLE2(1, i)))
 #endif
@@ -458,7 +458,7 @@ KFR_INTRIN_SHUFFLE_SWAP(f32, 2,
                         _mm_cvtsd_f64(_mm_castps_pd(KFR_swap_ps(_mm_castpd_ps(_mm_set1_pd(x.whole))))))
 #else
 KFR_INTRIN_SHUFFLE_CONCAT(f32, 2, _mm_setr_ps(x.low, x.high, y.low, y.high))
-KFR_INTRIN_SHUFFLE_SWAP(f32, 2, simd<f32, 2>(x.high, x.low))
+KFR_INTRIN_SHUFFLE_SWAP(f32, 2, simd<f32, 2>{ x.high, x.low })
 #endif
 
 #if defined CMT_COMPILER_IS_MSVC && defined CMT_ARCH_X32
@@ -521,7 +521,11 @@ KFR_INTRIN_SHUFFLE_LINEAR(i32, 4, 2, _mm_cvtsi64_si128(x.whole))
 // slice
 KFR_INTRIN_SHUFFLE_LINEAR(i32, 1, 4, _mm_cvtsi128_si32(x))
 KFR_INTRIN_SHUFFLE_LINEAR(u32, 1, 4, _mm_cvtsi128_si32(x))
+#if defined CMT_COMPILER_IS_MSVC && _MSC_VER > 1936
+KFR_INTRIN_SHUFFLE_LINEAR(i64, 1, 2, i64(x.m128i_i64[0]))
+#else
 KFR_INTRIN_SHUFFLE_LINEAR(i64, 1, 2, _mm_cvtsi128_si64(x))
+#endif
 KFR_INTRIN_SHUFFLE_LINEAR(u64, 1, 2, _mm_cvtsi128_si64(x))
 KFR_INTRIN_SHUFFLE_LINEAR(f32, 1, 4, _mm_cvtss_f32(x))
 KFR_INTRIN_SHUFFLE_LINEAR(f32, 2, 4, bitcast_anything<simd<float, 2>>(_mm_cvtsd_f64(_mm_castps_pd(x))))
@@ -712,8 +716,7 @@ KFR_INTRINSIC __m256i KFR_mm256_setr_m128i(__m128i x, __m128i y)
 #ifdef CMT_ARCH_AVX2
     return _mm256_inserti128_si256(_mm256_castsi128_si256(x), y, 1);
 #else
-    return _mm256_castps_si256(
-        _mm256_insertf128_ps(_mm256_castps128_ps256(_mm_castsi128_ps(x)), _mm_castsi128_ps(y), 1));
+    return _mm256_insertf128_si256(_mm256_castsi128_si256(x), y, 1);
 #endif
 }
 
@@ -920,8 +923,15 @@ static inline __m512i KFR_mm512_setr_epi16(i16 x0, i16 x1, i16 x2, i16 x3, i16 x
                                            i16 x22, i16 x23, i16 x24, i16 x25, i16 x26, i16 x27, i16 x28,
                                            i16 x29, i16 x30, i16 x31)
 {
+#ifdef CMT_COMPILER_GCC
+    typedef short v32hi __attribute__((__vector_size__(64)));
+    return __extension__(__m512i)(v32hi){ x0,  x1,  x2,  x3,  x4,  x5,  x6,  x7,  x8,  x9,  x10,
+                                          x11, x12, x13, x14, x15, x16, x17, x18, x19, x20, x21,
+                                          x22, x23, x24, x25, x26, x27, x28, x29, x30, x31 };
+#else
     return _mm512_set_epi16(x31, x30, x29, x28, x27, x26, x25, x24, x23, x22, x21, x20, x19, x18, x17, x16,
                             x15, x14, x13, x12, x11, x10, x9, x8, x7, x6, x5, x4, x3, x2, x1, x0);
+#endif
 }
 static inline __m512i KFR_mm512_setr_epi8(i8 x0, i8 x1, i8 x2, i8 x3, i8 x4, i8 x5, i8 x6, i8 x7, i8 x8,
                                           i8 x9, i8 x10, i8 x11, i8 x12, i8 x13, i8 x14, i8 x15, i8 x16,
@@ -932,10 +942,19 @@ static inline __m512i KFR_mm512_setr_epi8(i8 x0, i8 x1, i8 x2, i8 x3, i8 x4, i8
                                           i8 x49, i8 x50, i8 x51, i8 x52, i8 x53, i8 x54, i8 x55, i8 x56,
                                           i8 x57, i8 x58, i8 x59, i8 x60, i8 x61, i8 x62, i8 x63)
 {
+#ifdef CMT_COMPILER_GCC
+    typedef char v64qi __attribute__((__vector_size__(64)));
+    return __extension__(__m512i)(v64qi){ x0,  x1,  x2,  x3,  x4,  x5,  x6,  x7,  x8,  x9,  x10, x11, x12,
+                                          x13, x14, x15, x16, x17, x18, x19, x20, x21, x22, x23, x24, x25,
+                                          x26, x27, x28, x29, x30, x31, x32, x33, x34, x35, x36, x37, x38,
+                                          x39, x40, x41, x42, x43, x44, x45, x46, x47, x48, x49, x50, x51,
+                                          x52, x53, x54, x55, x56, x57, x58, x59, x60, x61, x62, x63 };
+#else
     return _mm512_set_epi8(x63, x62, x61, x60, x59, x58, x57, x56, x55, x54, x53, x52, x51, x50, x49, x48,
                            x47, x46, x45, x44, x43, x42, x41, x40, x39, x38, x37, x36, x35, x34, x33, x32,
                            x31, x30, x29, x28, x27, x26, x25, x24, x23, x22, x21, x20, x19, x18, x17, x16,
                            x15, x14, x13, x12, x11, x10, x9, x8, x7, x6, x5, x4, x3, x2, x1, x0);
+#endif
 }
 
 KFR_INTRINSIC __m512 KFR_mm512_setr_m256(__m256 x, __m256 y)
@@ -1077,7 +1096,7 @@ KFR_INTRINSIC simd<T, N> from_simd_array(const simd_array<T, N>& x) CMT_NOEXCEPT
 template <typename T, size_t N, size_t... indices>
 KFR_INTRINSIC simd<T, N> from_simd_array_impl(const simd_array<T, N>& x, csizes_t<indices...>) CMT_NOEXCEPT
 {
-    return { static_cast<unwrap_bit<T>>(x.val[indices])... };
+    return { unwrap_bit_value(x.val[indices])... };
 }
 
 template <typename T, size_t N, KFR_ENABLE_IF(is_simd_small_array<simd<T, N>>)>
@@ -1100,7 +1119,7 @@ KFR_INTRINSIC void simd_make(ctype_t<Tout>) CMT_NOEXCEPT = delete;
 template <typename Tout, typename Arg>
 KFR_INTRINSIC simd<Tout, 1> simd_make(ctype_t<Tout>, const Arg& arg) CMT_NOEXCEPT
 {
-    return simd<Tout, 1>{ static_cast<unwrap_bit<Tout>>(static_cast<Tout>(arg)) };
+    return simd<Tout, 1>{ unwrap_bit_value(static_cast<Tout>(arg)) };
 }
 
 template <typename T, size_t... indices, typename... Args, size_t N = sizeof...(indices)>
@@ -1179,9 +1198,10 @@ KFR_INTRINSIC simd<Tout, Nout> simd_bitcast(simd_cvt_t<Tout, Tin, N>, const simd
     constexpr size_t Nlow = prev_poweroftwo(N - 1);
     return simd_concat<Tout, Nlow * Nout / N, (N - Nlow) * Nout / N>(
         simd_bitcast(simd_cvt_t<Tout, Tin, Nlow>{},
-                     simd_shuffle(simd_t<Tin, N>{}, x, csizeseq<Nlow>, overload_auto)),
-        simd_bitcast(simd_cvt_t<Tout, Tin, N - Nlow>{},
-                     simd_shuffle(simd_t<Tin, N>{}, x, csizeseq<N - Nlow, Nlow>, overload_auto)));
+                     unwrap_bit_value(simd_shuffle(simd_t<Tin, N>{}, x, csizeseq<Nlow>, overload_auto))),
+        simd_bitcast(
+            simd_cvt_t<Tout, Tin, N - Nlow>{},
+            unwrap_bit_value(simd_shuffle(simd_t<Tin, N>{}, x, csizeseq<N - Nlow, Nlow>, overload_auto))));
 }
 
 template <typename T, size_t N>
@@ -1193,11 +1213,11 @@ KFR_INTRINSIC const simd<T, N>& simd_bitcast(simd_cvt_t<T, T, N>, const simd<T,
 template <typename T, size_t N, size_t index>
 KFR_INTRINSIC T simd_get_element(const simd<T, N>& value, csize_t<index>) CMT_NOEXCEPT
 {
-    return simd_shuffle(simd_t<T, N>{}, value, csizes<index>, overload_auto);
+    return wrap_bit_value<T>(simd_shuffle(simd_t<T, N>{}, value, csizes<index>, overload_auto));
 }
 
 template <typename T, size_t N, size_t index>
-KFR_INTRINSIC simd<T, N> simd_set_element(simd<T, N> value, csize_t<index>, T x) CMT_NOEXCEPT
+KFR_INTRINSIC simd<T, N> simd_set_element(simd<T, N> value, csize_t<index>, unwrap_bit<T> x) CMT_NOEXCEPT
 {
     not_optimized(CMT_FUNC_SIGNATURE);
     simd_array<T, N> arr = to_simd_array<T, N>(value);
@@ -1239,7 +1259,7 @@ KFR_INTRINSIC simd<T, N + N> simd_shuffle(simd2_t<T, N, N>, const simd<T, N>& x,
 template <typename T>
 KFR_INTRINSIC simd<T, 1> simd_broadcast(simd_t<T, 1>, identity<T> value) CMT_NOEXCEPT
 {
-    return { static_cast<unwrap_bit<T>>(value) };
+    return { unwrap_bit_value(value) };
 }
 
 template <typename T, size_t N, KFR_ENABLE_IF(N >= 2), size_t Nlow = prev_poweroftwo(N - 1)>
@@ -1309,8 +1329,7 @@ KFR_INTRINSIC simd<T, Nout> simd_shuffle(simd_t<T, N>, const simd<T, N>& x, csiz
     constexpr static unsigned indices_array[] = { static_cast<unsigned>(indices)... };
     return from_simd_array<T, Nout>(simd_shuffle_generic<T, Nout, N>(xx, indices_array));
 #else
-    return from_simd_array<T, Nout>(
-        { (indices >= N ? T() : static_cast<T>(to_simd_array<T, N>(x).val[indices]))... });
+    return from_simd_array<T, Nout>({ (indices >= N ? T() : to_simd_array<T, N>(x).val[indices])... });
 #endif
 }
 
@@ -1326,10 +1345,9 @@ KFR_INTRINSIC simd<T, Nout> simd_shuffle(simd2_t<T, N, N>, const simd<T, N>& x,
     constexpr static unsigned indices_array[] = { static_cast<unsigned>(indices)... };
     return from_simd_array<T, Nout>(simd_shuffle2_generic<T, Nout, N, N>(xx, yy, indices_array));
 #else
-    return from_simd_array<T, Nout>(
-        { (indices >= N * 2 ? T()
-           : indices >= N ? static_cast<T>(to_simd_array<T, N>(y).val[indices - N])
-                          : static_cast<T>(to_simd_array<T, N>(x).val[indices]))... });
+    return from_simd_array<T, Nout>({ (indices >= N * 2 ? T()
+                                       : indices >= N   ? to_simd_array<T, N>(y).val[indices - N]
+                                                        : to_simd_array<T, N>(x).val[indices])... });
 #endif
 }
 
@@ -1347,10 +1365,9 @@ KFR_INTRINSIC simd<T, Nout> simd_shuffle(simd2_t<T, N1, N2>, const simd<T, N1>&
     return from_simd_array<T, Nout>(simd_shuffle2_generic<T, Nout, N1, N2>(xx, yy, indices_array));
 #else
 
-    return from_simd_array<T, Nout>(
-        { (indices > N1 + N2 ? T()
-           : indices >= N1 ? static_cast<T>(to_simd_array<T, N2>(y).val[indices - N1])
-                           : static_cast<T>(to_simd_array<T, N1>(x).val[indices]))... });
+    return from_simd_array<T, Nout>({ (indices > N1 + N2 ? T()
+                                       : indices >= N1   ? to_simd_array<T, N2>(y).val[indices - N1]
+                                                         : to_simd_array<T, N1>(x).val[indices])... });
 #endif
 }
 
@@ -1433,7 +1450,7 @@ KFR_INTRINSIC T simd_get_element(const simd<T, N>& value, size_t index) CMT_NOEX
 }
 
 template <typename T, size_t N>
-KFR_INTRINSIC simd<T, N> simd_set_element(const simd<T, N>& value, size_t index, T x) CMT_NOEXCEPT
+KFR_INTRINSIC simd<T, N> simd_set_element(const simd<T, N>& value, size_t index, unwrap_bit<T> x) CMT_NOEXCEPT
 {
     simd_array<T, N> arr = to_simd_array<T, N>(value);
     arr.val[index]       = x;
@@ -1442,8 +1459,8 @@ KFR_INTRINSIC simd<T, N> simd_set_element(const simd<T, N>& value, size_t index,
 
 #define SIMD_TYPE_INTRIN(T, N, TO_SCALAR, FROM_SCALAR, FROM_BROADCAST, FROM_ZERO)                            \
     KFR_INTRINSIC T simd_to_scalar(simd_t<T, N>, const simd<T, N>& x) { return TO_SCALAR; }                  \
-    KFR_INTRINSIC simd<T, N> simd_from_scalar(simd_t<T, N>, T x) { return FROM_SCALAR; }                     \
-    KFR_INTRINSIC simd<T, N> simd_from_broadcast(simd_t<T, N>, T x) { return FROM_BROADCAST; }               \
+    KFR_INTRINSIC simd<T, N> simd_from_scalar(simd_t<T, N>, unwrap_bit<T> x) { return FROM_SCALAR; }         \
+    KFR_INTRINSIC simd<T, N> simd_from_broadcast(simd_t<T, N>, unwrap_bit<T> x) { return FROM_BROADCAST; }   \
     KFR_INTRINSIC simd<T, N> simd_from_zero(simd_t<T, N>) { return FROM_ZERO; }
 
 #define SIMD_TYPE_INTRIN_EX(T, N, TO_SCALAR, FROM_SCALAR, FROM_BROADCAST, FROM_ZERO, GET_LOW, GET_HIGH,      \
@@ -1496,7 +1513,11 @@ KFR_INTRINSIC simd<T, N> simd_from_halves(simd_t<T, N>, const simd<T, N / 2>& x,
 KFR_INTRINSIC simd<float, 4> simd_from_halves(simd_t<float, 4>, const simd<float, 2>& x,
                                               const simd<float, 2>& y)
 {
+#ifndef KFR_f32x2_array
     return _mm_castpd_ps(_mm_setr_pd(x.whole, y.whole));
+#else
+    return _mm_setr_ps(x.low, x.high, y.low, y.high);
+#endif
 }
 
 KFR_INTRINSIC simd<double, 2> simd_from_halves(simd_t<double, 2>, const simd<double, 1>& x,
@@ -1547,7 +1568,7 @@ KFR_INTRINSIC simd<double, 2> simd_vec_shuffle(simd_t<double, 2>, const simd<dou
 template <uint8_t max>
 KFR_INTRINSIC constexpr uint8_t vec_idx(size_t value)
 {
-    return value >= max ? 0 : value;
+    return value >= static_cast<size_t>(max) ? 0 : static_cast<uint8_t>(value);
 }
 
 #ifdef CMT_ARCH_AVX512
@@ -1825,8 +1846,6 @@ KFR_INTRINSIC simd<T, Nout> universal_shuffle(simd_t<T, Nin>, const simd<T, Nin>
 {
     using Indices = csizes_t<indices...>;
 
-    constexpr bool floating = typeclass<T> == datatype::f;
-
     constexpr size_t minwidth = minimum_vector_width<T>;
     constexpr size_t maxwidth = vector_width<T>;
     constexpr size_t minindex = cminof(Indices{});
