@@ -570,12 +570,16 @@ public:
             PW_KEY_MEDIA_CATEGORY, "Duplex",
             PW_KEY_MEDIA_ROLE, "DSP",
             PW_KEY_MEDIA_NAME, "ossia",
+            PW_KEY_NODE_NAME, "ossia",
+            PW_KEY_NODE_GROUP, "group.dsp.0",
+            PW_KEY_NODE_DESCRIPTION, "ossia score",
             PW_KEY_NODE_LATENCY, fmt::format("{}/{}", setup.buffer_size, setup.rate).c_str(),
             PW_KEY_NODE_FORCE_QUANTUM, fmt::format("{}", setup.buffer_size).c_str(),
             PW_KEY_NODE_LOCK_QUANTUM, "true",
-            PW_KEY_NODE_RATE, fmt::format("{}/{}", 1, setup.rate).c_str(),
-            PW_KEY_NODE_FORCE_RATE, fmt::format("{}/{}", 1, setup.rate).c_str(),
-            PW_KEY_NODE_LOCK_RATE, "true",
+            PW_KEY_NODE_TRANSPORT_SYNC, "true",
+            //PW_KEY_NODE_RATE, fmt::format("{}/{}", 1, setup.rate).c_str(),
+            PW_KEY_NODE_FORCE_RATE, fmt::format("{}", setup.rate).c_str(),
+            //PW_KEY_NODE_LOCK_RATE, "true",
             //PW_KEY_NODE_ALWAYS_PROCESS, "true",
             PW_KEY_NODE_PAUSE_ON_IDLE, "false",
             PW_KEY_NODE_SUSPEND_ON_IDLE, "false",
