@@ -30,12 +30,12 @@ TEST_CASE("test_oscquery_osc_out", "test_oscquery_osc_out")
   using conf = ossia::net::osc_protocol_configuration;
 
   auto osc = ossia::net::make_osc_protocol(
-      ctx,
-      {.mode = conf::HOST,
-       .version = conf::OSC1_1,
-       .transport = ossia::net::udp_configuration{
-           {.local = std::nullopt,
-            .remote = ossia::net::outbound_socket_configuration{"127.0.0.1", shared}}}});
+      ctx, {.mode = conf::HOST,
+            .version = conf::OSC1_1,
+            .transport = ossia::net::udp_configuration{
+                {.local = std::nullopt,
+                 .remote = ossia::net::outbound_socket_configuration{
+                     .host = "127.0.0.1", .port = shared}}}});
   auto oscquery = std::make_unique<ossia::oscquery_asio::oscquery_server_protocol>(ctx);
 
   auto multiplex = std::make_unique<ossia::net::multiplex_protocol>();
@@ -46,7 +46,8 @@ TEST_CASE("test_oscquery_osc_out", "test_oscquery_osc_out")
   device.set_echo(true);
 
   const auto udp_conf = ossia::net::udp_configuration{
-      {.local = ossia::net::inbound_socket_configuration{"0.0.0.0", shared},
+      {.local
+       = ossia::net::inbound_socket_configuration{.bind = "0.0.0.0", .port = shared},
        .remote = std::nullopt}};
   ossia::net::generic_device remote{
       ossia::net::make_osc_protocol(
@@ -105,12 +106,12 @@ TEST_CASE("test_oscquery_osc_large", "test_oscquery_osc_large")
   using conf = ossia::net::osc_protocol_configuration;
 
   auto osc = ossia::net::make_osc_protocol(
-      ctx,
-      {.mode = conf::HOST,
-       .version = conf::OSC1_1,
-       .transport = ossia::net::udp_configuration{
-           {.local = std::nullopt,
-            .remote = ossia::net::outbound_socket_configuration{"127.0.0.1", shared}}}});
+      ctx, {.mode = conf::HOST,
+            .version = conf::OSC1_1,
+            .transport = ossia::net::udp_configuration{
+                {.local = std::nullopt,
+                 .remote = ossia::net::outbound_socket_configuration{
+                     .host = "127.0.0.1", .port = shared}}}});
   auto oscquery = std::make_unique<ossia::oscquery_asio::oscquery_server_protocol>(ctx);
 
   auto multiplex = std::make_unique<ossia::net::multiplex_protocol>();
@@ -137,12 +138,12 @@ TEST_CASE("test_multiplex_remove", "test_multiplex_remove")
   using conf = ossia::net::osc_protocol_configuration;
 
   auto osc = ossia::net::make_osc_protocol(
-      ctx,
-      {.mode = conf::HOST,
-       .version = conf::OSC1_1,
-       .transport = ossia::net::udp_configuration{
-           {.local = std::nullopt,
-            .remote = ossia::net::outbound_socket_configuration{"127.0.0.1", shared}}}});
+      ctx, {.mode = conf::HOST,
+            .version = conf::OSC1_1,
+            .transport = ossia::net::udp_configuration{
+                {.local = std::nullopt,
+                 .remote = ossia::net::outbound_socket_configuration{
+                     .host = "127.0.0.1", .port = shared}}}});
   auto oscquery = std::make_unique<ossia::oscquery_asio::oscquery_server_protocol>(ctx);
 
   auto multiplex = std::make_unique<ossia::net::multiplex_protocol>();
@@ -203,7 +204,7 @@ TEST_CASE("test_multiplex_remove", "test_multiplex_remove")
               .transport = ossia::net::udp_configuration{
                   {.local = std::nullopt,
                    .remote = ossia::net::outbound_socket_configuration{
-                       {"127.0.0.1", shared}}}}});
+                       .host = "127.0.0.1", .port = shared}}}});
     proto->expose_to(std::move(o));
   }
 
