@@ -1,5 +1,5 @@
 /* LLFIO error handling
-(C) 2018-2020 Niall Douglas <http://www.nedproductions.biz/> (24 commits)
+(C) 2018-2022 Niall Douglas <http://www.nedproductions.biz/> (24 commits)
 File Created: June 2018
 
 
@@ -57,7 +57,11 @@ as that (a) enables safe header only LLFIO on Windows (b) produces better codege
 #include "outcome/try.hpp"
 // Bring in status code utility
 #include "outcome/experimental/coroutine_support.hpp"
-#include "outcome/experimental/status-code/include/system_code_from_exception.hpp"
+#if !OUTCOME_USE_SYSTEM_STATUS_CODE && __has_include("outcome/experimental/status-code/include/status-code/system_code_from_exception.hpp")
+#include "outcome/experimental/status-code/include/status-code/system_code_from_exception.hpp"
+#else
+#include <status-code/system_code_from_exception.hpp>
+#endif
 #if !defined(LLFIO_ENABLE_COROUTINES) && defined(OUTCOME_FOUND_COROUTINE_HEADER)
 #define LLFIO_ENABLE_COROUTINES 1
 #endif
@@ -190,8 +194,15 @@ public:
   static inline constexpr const file_io_error_domain &get();
 #endif
 
+  virtual typename _base::payload_info_t payload_info() const noexcept override
+  {
+    return {sizeof(value_type), sizeof(SYSTEM_ERROR2_NAMESPACE::status_code_domain *) + sizeof(value_type),
+            (alignof(value_type) > alignof(SYSTEM_ERROR2_NAMESPACE::status_code_domain *)) ? alignof(value_type) :
+                                                                                             alignof(SYSTEM_ERROR2_NAMESPACE::status_code_domain *)};
+  }
+
 protected:
-  virtual inline string_ref _do_message(const SYSTEM_ERROR2_NAMESPACE::status_code<void> &code) const noexcept override final
+  virtual inline string_ref _do_message(const SYSTEM_ERROR2_NAMESPACE::status_code<void> &code) const noexcept override
   {
     assert(code.domain() == *this);
     const auto &v = static_cast<const SYSTEM_ERROR2_NAMESPACE::status_code<file_io_error_domain> &>(code);  // NOLINT
@@ -242,6 +253,34 @@ protected:
     memcpy(p, ret.c_str(), ret.size() + 1);
     return atomic_refcounted_string_ref(p, ret.size());
   }
+#if defined(__GNUC__) && !defined(__clang__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wclass-memaccess"
+#endif
+  virtual bool _do_erased_copy(SYSTEM_ERROR2_NAMESPACE::status_code<void> &dst, const SYSTEM_ERROR2_NAMESPACE::status_code<void> &src,
+                               typename _base::payload_info_t dstinfo) const override
+  {
+    // Note that dst may not have its domain set
+    const auto srcinfo = payload_info();
+    if(dstinfo.total_size >= srcinfo.total_size)
+    {
+      // Identity
+      memcpy(&dst, &src, srcinfo.total_size);
+      return true;
+    }
+    if(dstinfo.total_size >= sizeof(SYSTEM_ERROR2_NAMESPACE::status_code_domain *) + sizeof(value_type::sc))
+    {
+      // Allow dropping LLFIO additional state
+      const auto *basedomain = &_base::get();
+      memcpy(&dst, &src, sizeof(SYSTEM_ERROR2_NAMESPACE::status_code_domain *) + sizeof(value_type::sc));
+      memcpy(&dst, &basedomain, sizeof(SYSTEM_ERROR2_NAMESPACE::status_code_domain *));
+      return true;
+    }
+    return false;
+  }
+#if defined(__GNUC__) && !defined(__clang__)
+#pragma GCC diagnostic pop
+#endif
 };
 #if __cplusplus >= 201402L || defined(_MSC_VER)
 template <class BaseStatusCodeDomain> constexpr file_io_error_domain<BaseStatusCodeDomain> file_io_error_domain_inst = {};
@@ -263,7 +302,7 @@ namespace detail
 #endif  // LLFIO_DISABLE_PATHS_IN_FAILURE_INFO
 
 //! An erased status code
-using file_io_error = SYSTEM_ERROR2_NAMESPACE::errored_status_code<SYSTEM_ERROR2_NAMESPACE::erased<detail::file_io_error_domain_value_system_code>>;
+using file_io_error = SYSTEM_ERROR2_NAMESPACE::erased_errored_status_code<detail::file_io_error_domain_value_system_code>;
 
 
 template <class T> using result = OUTCOME_V2_NAMESPACE::experimental::status_result<T, file_io_error>;
@@ -323,7 +362,10 @@ inline file_io_error ntkernel_error(SYSTEM_ERROR2_NAMESPACE::win32::NTSTATUS c);
 
 namespace detail
 {
-  inline std::ostream &operator<<(std::ostream &s, const file_io_error &v) { return s << "llfio::file_io_error(" << v.message().c_str() << ")"; }
+  inline std::ostream &operator<<(std::ostream &s, const file_io_error &v)
+  {
+    return s << "llfio::file_io_error(" << v.message().c_str() << ")";
+  }
 }  // namespace detail
 inline file_io_error error_from_exception(std::exception_ptr &&ep = std::current_exception(),
                                           SYSTEM_ERROR2_NAMESPACE::system_code not_matched = errc::resource_unavailable_try_again) noexcept
@@ -384,10 +426,8 @@ private:
   uint16_t _tls_path_id1{static_cast<uint16_t>(-1)}, _tls_path_id2{static_cast<uint16_t>(-1)};
   // The id of the relevant log entry in the LLFIO log (if logging enabled)
   size_t _log_id{static_cast<size_t>(-1)};
-
-public:
 #endif
-
+public:
   //! Default constructor
   error_info() = default;
   // Explicit construction from an error code
