@@ -35,8 +35,9 @@
 
 #include "../ds/ds.h"
 #include "entropy.h"
+#include "snmalloc/stl/new.h"
 
-#include <cstdint>
+#include <stdint.h>
 
 namespace snmalloc
 {
@@ -182,7 +183,7 @@ namespace snmalloc
         };
 
         SNMALLOC_NO_UNIQUE_ADDRESS
-        std::conditional_t<mitigations(freelist_backward_edge), Prev, Empty>
+        stl::conditional_t<mitigations(freelist_backward_edge), Prev, Empty>
           prev{};
 
       public:
@@ -197,7 +198,7 @@ namespace snmalloc
         {
           auto n_wild = Object::decode_next(
             address_cast(&this->next_object),
-            this->atomic_next_object.load(std::memory_order_acquire),
+            this->atomic_next_object.load(stl::memory_order_acquire),
             key,
             key_tweak);
           auto n_tame = domesticate(n_wild);
@@ -265,7 +266,7 @@ namespace snmalloc
       static BHeadPtr<BView, BQueue> make(CapPtr<void, BView> p)
       {
         return CapPtr<Object::T<BQueue>, BView>::unsafe_from(
-          new (p.unsafe_ptr()) Object::T());
+          new (p.unsafe_ptr(), placement_token) Object::T());
       }
 
       /**
@@ -377,7 +378,7 @@ namespace snmalloc
           "Free Object View must be domesticated, justifying raw pointers");
 
         static_assert(
-          std::is_same_v<
+          stl::is_same_v<
             typename BQueue::template with_wildness<
               capptr::dimension::Wildness::Tame>,
             BView>,
@@ -472,7 +473,7 @@ namespace snmalloc
         // so requires release semantics.
         curr->atomic_next_object.store(
           encode_next(address_cast(&curr->next_object), next, key, key_tweak),
-          std::memory_order_release);
+          stl::memory_order_release);
       }
 
       template<
@@ -491,7 +492,7 @@ namespace snmalloc
             BQueuePtr<BQueue>(nullptr),
             key,
             key_tweak),
-          std::memory_order_relaxed);
+          stl::memory_order_relaxed);
       }
     };
 
@@ -528,6 +529,7 @@ namespace snmalloc
 
     protected:
       constexpr Prev(address_t prev) : prev(prev) {}
+
       constexpr Prev() = default;
 
       address_t replace(address_t next)
@@ -553,7 +555,7 @@ namespace snmalloc
     };
 
     using IterBase =
-      std::conditional_t<mitigations(freelist_backward_edge), Prev, NoPrev>;
+      stl::conditional_t<mitigations(freelist_backward_edge), Prev, NoPrev>;
 
     /**
      * Used to iterate a free list in object space.
@@ -570,10 +572,12 @@ namespace snmalloc
       struct KeyTweak
       {
         address_t key_tweak = 0;
+
         SNMALLOC_FAST_PATH address_t get()
         {
           return key_tweak;
         }
+
         void set(address_t kt)
         {
           key_tweak = kt;
@@ -588,11 +592,12 @@ namespace snmalloc
         {
           return 0;
         }
+
         void set(address_t) {}
       };
 
       SNMALLOC_NO_UNIQUE_ADDRESS
-      std::conditional_t<
+      stl::conditional_t<
         mitigations(freelist_forward_edge) ||
           mitigations(freelist_backward_edge),
         KeyTweak,
@@ -696,11 +701,11 @@ namespace snmalloc
        */
 
       // Pointer to the first element.
-      std::array<void*, LENGTH> head{nullptr};
+      stl::Array<void*, LENGTH> head{nullptr};
       // Pointer to the reference to the last element.
       // In the empty case end[i] == &head[i]
       // This enables branch free enqueuing.
-      std::array<void**, LENGTH> end{nullptr};
+      stl::Array<void**, LENGTH> end{nullptr};
 
       [[nodiscard]] Object::BQueuePtr<BQueue>* cast_end(uint32_t ix) const
       {
@@ -719,7 +724,7 @@ namespace snmalloc
       }
 
       SNMALLOC_NO_UNIQUE_ADDRESS
-      std::array<uint16_t, RANDOM ? 2 : (TRACK_LENGTH ? 1 : 0)> length{};
+      stl::Array<uint16_t, RANDOM ? 2 : (TRACK_LENGTH ? 1 : 0)> length{};
 
     public:
       constexpr Builder() = default;
@@ -770,7 +775,7 @@ namespace snmalloc
        * lists, which will be randomised at the other end.
        */
       template<bool RANDOM_ = RANDOM>
-      std::enable_if_t<!RANDOM_> add(
+      stl::enable_if_t<!RANDOM_> add(
         Object::BHeadPtr<BView, BQueue> n,
         const FreeListKey& key,
         address_t key_tweak)
@@ -892,16 +897,16 @@ namespace snmalloc
       }
 
       template<bool RANDOM_ = RANDOM>
-      std::enable_if_t<!RANDOM_, size_t> extract_segment_length()
+      stl::enable_if_t<!RANDOM_, size_t> extract_segment_length()
       {
         static_assert(RANDOM_ == RANDOM, "Don't set SFINAE parameter!");
         return length[0];
       }
 
       template<bool RANDOM_ = RANDOM>
-      std::enable_if_t<
+      stl::enable_if_t<
         !RANDOM_,
-        std::pair<
+        stl::Pair<
           Object::BHeadPtr<BView, BQueue>,
           Object::BHeadPtr<BView, BQueue>>>
       extract_segment(const FreeListKey& key, address_t key_tweak)
