@@ -1,6 +1,6 @@
 #pragma once
 #include <OnnxModels/Utils.hpp>
-
+#include <Onnx/helpers/Resnet.hpp>
 #include <cmath>
 #include <halp/controls.hpp>
 #include <halp/geometry.hpp>
@@ -22,14 +22,14 @@ struct DetectedElement
   halp_field_names(name, probability);
 };
 
-struct ResnetDetector
+struct ResnetDetector : OnnxObject
 {
 public:
   halp_meta(name, "Resnet detector");
   halp_meta(c_name, "resnet");
   halp_meta(category, "AI/Computer Vision");
   halp_meta(author, "Resnet authors, Onnxruntime");
-  halp_meta(description, "Resnet recognizer using DNN.");
+  halp_meta(description, "Resnet recognizer using a DNN model.");
   halp_meta(uuid, "9f4b7448-5bb5-4db6-8c96-57d53896208b");
   halp_meta(
       manual_url,
@@ -39,7 +39,13 @@ public:
   {
     halp::fixed_texture_input<"In"> image;
     ModelPort model;
-    halp::lineedit<"Classes", ""> classes;
+    struct : halp::lineedit<"Classes", "">
+    {
+      void update(ResnetDetector& self)
+      {
+        self.resnet.loadClasses(this->value);
+      }
+    } classes;
     halp::xy_spinboxes_i32<"Model input resolution", halp::range{1, 2048, 224}>
         resolution;
   } inputs;
@@ -62,5 +68,8 @@ public:
 
 private:
   std::unique_ptr<Onnx::OnnxRunContext> ctx;
+
+  Resnet resnet;
+  boost::container::vector<float> storage;
 };
 }
