@@ -1,6 +1,6 @@
 #pragma once
+#include <Onnx/helpers/Yolo.hpp>
 #include <OnnxModels/Utils.hpp>
-
 #include <cmath>
 #include <halp/controls.hpp>
 #include <halp/geometry.hpp>
@@ -27,11 +27,11 @@ struct DetectedYoloBlob
 struct YOLO7BlobDetector : OnnxObject
 {
 public:
-  halp_meta(name, "YOLOv7 Blob");
-  halp_meta(c_name, "yolov7_blob");
+  halp_meta(name, "YOLO Blob");
+  halp_meta(c_name, "yolo_blob");
   halp_meta(category, "AI/Computer Vision");
   halp_meta(author, "YOLO authors, Kin-Yiu Wong, Onnxruntime");
-  halp_meta(description, "Identifies objects using a YOLOv7 blob model.");
+  halp_meta(description, "Identifies objects using a YOLO blob model.");
   halp_meta(uuid, "3303df15-5774-4abc-b636-b51c9bb6d1fb");
   halp_meta(
       manual_url,
@@ -47,6 +47,8 @@ public:
     } classes;
     halp::xy_spinboxes_i32<"Model input resolution", halp::range{1, 2048, 640}>
         resolution;
+    halp::knob_f32<"Min. confidence"> confidence;
+    halp::knob_f32<"IoU threshold"> iou_threshold;
   } inputs;
 
   struct
@@ -71,5 +73,6 @@ private:
   std::unique_ptr<Onnx::OnnxRunContext> ctx;
   std::vector<std::string> classes;
   boost::container::vector<float> storage;
+  Yolo::YOLO_blob detector;
 };
 }
