@@ -13,13 +13,21 @@ public:
   halp_meta(name, "Roll")
   halp_meta(category, "Gestures")
   halp_meta(c_name, "puara_roll")
-  halp_meta(uuid, "3135b5e0-39a6-4151-8ae4-a657d577eab8")
+  halp_meta(
+      description,
+      "Calculates the roll angle of a device using motion sensors, with optional "
+      "unwrapping, smoothing, and wrapping.")
+  halp_meta(manual_url, "https://github.com/Puara/puara-gestures/")
+  halp_meta(uuid, "c8060aec-462b-4e3c-bb43-fa8fd1d4cdec")
 
-  struct ins
+  struct
   {
     halp::val_port<"Acceleration", puara_gestures::Coord3D> accel;
-    halp::val_port<"Gyrosocope", puara_gestures::Coord3D> gyro;
+    halp::val_port<"Gyroscope", puara_gestures::Coord3D> gyro;
     halp::val_port<"Magnetometer", puara_gestures::Coord3D> mag;
+    halp::toggle<"Enable Unwrap", halp::toggle_setup{.init = true}> enable_unwrap;
+    halp::toggle<"Enable Smooth", halp::toggle_setup{.init = true}> enable_smooth;
+    halp::toggle<"Enable Wrap", halp::toggle_setup{.init = false}> enable_wrap;
   } inputs;
 
   struct
@@ -35,5 +43,4 @@ public:
 
   puara_gestures::Roll impl;
 };
-
 }
