@@ -1,4 +1,5 @@
 #pragma once
+#include <score/graphics/DefaultControlImpl.hpp>
 #include <score/model/Skin.hpp>
 #include <score/widgets/DoubleSpinBox.hpp>
 #include <score/widgets/SignalUtils.hpp>
@@ -8,6 +9,7 @@
 #include <QGraphicsProxyWidget>
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
+#include <QGuiApplication>
 #include <QKeyEvent>
 #include <QPainter>
 #include <QPointer>
@@ -99,7 +101,17 @@ struct DefaultGraphicsSliderImpl
       double curPos = self.from01(ossia::clamp(posX, 0., srect.width()) / srect.width());
       if(curPos != self.m_value)
       {
-        self.m_value = curPos;
+        if constexpr(std::is_same_v<decltype(self.m_value), int>)
+        {
+          self.m_value = curPos;
+        }
+        else
+        {
+          double ratio = qGuiApp->keyboardModifiers() & Qt::CTRL ? 0.1 : 1.;
+          self.m_value = std::clamp(
+              double(self.m_value + ((curPos - self.m_value) * ratio)), 0., 1.);
+        }
+
         self.sliderMoved();
         self.update();
       }
@@ -117,7 +129,16 @@ struct DefaultGraphicsSliderImpl
       double curPos = self.from01(ossia::clamp(posX, 0., srect.width()) / srect.width());
       if(curPos != self.m_value)
       {
-        self.m_value = curPos;
+        if constexpr(std::is_same_v<decltype(self.m_value), int>)
+        {
+          self.m_value = curPos;
+        }
+        else
+        {
+          double ratio = qGuiApp->keyboardModifiers() & Qt::CTRL ? 0.1 : 1.;
+          self.m_value = std::clamp(
+              double(self.m_value + ((curPos - self.m_value) * ratio)), 0., 1.);
+        }
         self.update();
       }
     }
@@ -151,10 +172,8 @@ struct DefaultGraphicsSliderImpl
 
       auto con = QObject::connect(
           w, SignalUtils::QDoubleSpinBox_valueChanged_double(), &self,
-          [&self](double v) {
-        self.m_value = self.unmap(v);
-        self.sliderMoved();
-        self.update();
+          [&self, obj, scene = self.scene()](double v) {
+        DefaultControlImpl::editWidgetInContextMenu(self, scene, obj, v);
       });
 
       QObject::connect(
@@ -179,6 +198,16 @@ struct DefaultGraphicsSliderImpl
   template <typename T>
   static void mouseDoubleClickEvent(T& self, QGraphicsSceneMouseEvent* event)
   {
+    self.m_value = self.unmap(self.init);
+
+    self.m_grab = true;
+    self.sliderMoved();
+    self.sliderReleased();
+    self.m_grab = false;
+
+    self.update();
+
+    event->accept();
   }
 };
 
