@@ -19,4 +19,5 @@ PROCESS_METADATA(
     "ossia score", (QStringList{"Curve", "Automation"}), {},
     {std::vector<Process::PortType>{Process::PortType::Message}},
     QUrl("https://ossia.io/score-docs/in-depth/automations.html"),
-    Process::ProcessFlags::SupportsTemporal)
+    Process::ProcessFlags::SupportsTemporal
+        | Process::ProcessFlags::ItemRequiresUniqueFocus)
