@@ -8,6 +8,8 @@
 #include <score/plugins/application/GUIApplicationPlugin.hpp>
 #include <score/plugins/documentdelegate/plugin/DocumentPlugin.hpp>
 
+#include <QTimer>
+
 #include <score_plugin_engine_export.h>
 
 #include <memory>
@@ -58,11 +60,13 @@ public:
   void on_createdDocument(score::Document& doc) override;
   void on_documentChanged(score::Document* olddoc, score::Document* newdoc) override;
 
-  QWidget* setupTimingWidget(QLabel*) const;
+  QWidget* setupTimingWidget(QLabel*);
   void initLocalTreeNodes(LocalTree::DocumentPlugin&);
 
   Execution::ExecutionController& execution() { return m_execution; }
 
+  QTimer execution_ui_clock_timer{};
+
 private:
   Execution::PlayContextMenu m_playActions;
   Execution::ExecutionController m_execution;
