@@ -17,6 +17,8 @@ struct ProcessUBO
   int32_t passIndex{};
   int32_t frameIndex{};
 
+  float padding0[1];
+  float renderSize[2]{2048, 2048};
   float date[4]{0.f, 0.f, 0.f, 0.f};
   float mouse[4]{0.5f, 0.5f, 0.5f, 0.5f};
   float channelTime[4]{0.5f, 0.5f, 0.5f, 0.5f};
@@ -36,10 +38,11 @@ struct ModelCameraUBO
   float projection[16]{};
   float modelNormal[9]{};
   float padding[3]; // Needed as a mat3 needs a bit more space...
+  float fov = 90.;
 };
 
-    static_assert(
-        sizeof(ModelCameraUBO) == sizeof(float) * (16 + 16 + 16 + 16 + 16 + 9 + 3));
+static_assert(
+    sizeof(ModelCameraUBO) == sizeof(float) * (16 + 16 + 16 + 16 + 16 + 9 + 3 + 1));
 
 /**
  * @brief UBO shared across all entities shown on the same output.
