@@ -12,7 +12,7 @@ namespace score::gfx
 void defaultPassesInit(
     PassMap& passes, const std::vector<Edge*>& edges, RenderList& renderer,
     const Mesh& mesh, const QShader& v, const QShader& f, QRhiBuffer* processUBO,
-    QRhiBuffer* matUBO, const std::vector<Sampler>& samplers,
+    QRhiBuffer* matUBO, std::span<const Sampler> samplers,
     std::span<QRhiShaderResourceBinding> additionalBindings)
 {
   SCORE_ASSERT(passes.empty());
