@@ -28,18 +28,36 @@ public:
   Device::DeviceSettings getSettings() const override;
   void setSettings(const Device::DeviceSettings& settings) override;
 
+  std::pair<int, int> universeRange() const noexcept;
+
 private:
+  void addLEDs(int mode);
+  void addFixture(QString manufacturer, QString name);
+  void addDimmer();
   void updateHosts(int protocolindex);
   void updateTable();
+
+  void addressChanged(int row);
+  void universeChanged(int row);
+
+  QString newFixtureName(QString name);
   QLineEdit* m_deviceNameEdit{};
   QComboBox* m_host{};
   QSpinBox* m_rate{};
   QSpinBox* m_universe{};
+  QSpinBox* m_universe_count{};
+  QSpinBox* m_channels_per_universe{};
   QComboBox* m_transport{};
+  QCheckBox* m_multicast{};
   QRadioButton* m_source{};
   QRadioButton* m_sink{};
   QTableWidget* m_fixturesWidget{};
   QPushButton* m_addFixture{};
+  QPushButton* m_addGenericDimmer{};
+  QPushButton* m_addGenericRGB{};
+  QPushButton* m_addLEDStrip{};
+  QPushButton* m_addLEDPane{};
+  QPushButton* m_addLEDBox{};
   QPushButton* m_rmFixture{};
   std::vector<Artnet::Fixture> m_fixtures;
 };
