@@ -5,9 +5,13 @@
 #include <score/serialization/DataStreamVisitor.hpp>
 #include <score/serialization/JSONVisitor.hpp>
 #include <score/serialization/StdVariantSerialization.hpp>
+#include <score/serialization/VariantSerialization.hpp>
 
 JSON_METADATA(Protocols::Artnet::SingleCapability, "SingleCapability")
 JSON_METADATA(std::vector<Protocols::Artnet::RangeCapability>, "RangeCapabilities")
+JSON_METADATA(Protocols::Artnet::LEDStripLayout, "LEDStripLayout")
+JSON_METADATA(Protocols::Artnet::LEDPaneLayout, "LEDPaneLayout")
+JSON_METADATA(Protocols::Artnet::LEDVolumeLayout, "LEDVolumeLayout")
 
 template <>
 void DataStreamReader::read(const Protocols::Artnet::SingleCapability& n)
@@ -87,6 +91,104 @@ void JSONWriter::write(Protocols::Artnet::RangeCapability& n)
   n.range <<= obj["Range"];
 }
 
+template <>
+void DataStreamReader::read(const Protocols::Artnet::LEDStripLayout& n)
+{
+  m_stream << n.diodes << n.length << n.reverse;
+  insertDelimiter();
+}
+
+template <>
+void DataStreamWriter::write(Protocols::Artnet::LEDStripLayout& n)
+{
+  m_stream >> n.diodes >> n.length >> n.reverse;
+  checkDelimiter();
+}
+
+template <>
+void JSONReader::read(const Protocols::Artnet::LEDStripLayout& n)
+{
+  stream.StartObject();
+  obj["Diodes"] = n.diodes;
+  obj["Length"] = n.length;
+  obj["Reverse"] = n.reverse;
+  stream.EndObject();
+}
+
+template <>
+void JSONWriter::write(Protocols::Artnet::LEDStripLayout& n)
+{
+  n.diodes <<= obj["Diodes"];
+  n.length <<= obj["Length"];
+  n.reverse <<= obj["Reverse"];
+}
+
+template <>
+void DataStreamReader::read(const Protocols::Artnet::LEDPaneLayout& n)
+{
+  m_stream << n.diodes << n.width << n.height;
+  insertDelimiter();
+}
+
+template <>
+void DataStreamWriter::write(Protocols::Artnet::LEDPaneLayout& n)
+{
+  m_stream >> n.diodes >> n.width >> n.height;
+  checkDelimiter();
+}
+
+template <>
+void JSONReader::read(const Protocols::Artnet::LEDPaneLayout& n)
+{
+  stream.StartObject();
+  obj["Diodes"] = n.diodes;
+  obj["Width"] = n.width;
+  obj["Height"] = n.height;
+  stream.EndObject();
+}
+
+template <>
+void JSONWriter::write(Protocols::Artnet::LEDPaneLayout& n)
+{
+  n.diodes <<= obj["Diodes"];
+  n.width <<= obj["Width"];
+  n.height <<= obj["Height"];
+}
+
+template <>
+void DataStreamReader::read(const Protocols::Artnet::LEDVolumeLayout& n)
+{
+  m_stream << n.diodes << n.width << n.height << n.depth;
+  insertDelimiter();
+}
+
+template <>
+void DataStreamWriter::write(Protocols::Artnet::LEDVolumeLayout& n)
+{
+  m_stream >> n.diodes >> n.width >> n.height >> n.depth;
+  checkDelimiter();
+}
+
+template <>
+void JSONReader::read(const Protocols::Artnet::LEDVolumeLayout& n)
+{
+  stream.StartObject();
+  obj["Diodes"] = n.diodes;
+  obj["Width"] = n.width;
+  obj["Height"] = n.height;
+  obj["Depth"] = n.depth;
+  stream.EndObject();
+}
+
+template <>
+void JSONWriter::write(Protocols::Artnet::LEDVolumeLayout& n)
+{
+  n.diodes <<= obj["Diodes"];
+  n.width <<= obj["Width"];
+  n.height <<= obj["Height"];
+  n.depth <<= obj["Depth"];
+}
+
 template <>
 void DataStreamReader::read(const Protocols::Artnet::Channel& n)
 {
@@ -153,14 +255,16 @@ void JSONWriter::write(Protocols::Artnet::ModeInfo& n)
 template <>
 void DataStreamReader::read(const Protocols::Artnet::Fixture& n)
 {
-  m_stream << n.fixtureName << n.modeName << n.mode << n.controls << n.address;
+  m_stream << n.fixtureName << n.modeName << n.mode << n.controls << n.led << n.address
+           << n.universe;
   insertDelimiter();
 }
 
 template <>
 void DataStreamWriter::write(Protocols::Artnet::Fixture& n)
 {
-  m_stream >> n.fixtureName >> n.modeName >> n.mode >> n.controls >> n.address;
+  m_stream >> n.fixtureName >> n.modeName >> n.mode >> n.controls >> n.led >> n.address
+      >> n.universe;
   checkDelimiter();
 }
 
@@ -172,7 +276,11 @@ void JSONReader::read(const Protocols::Artnet::Fixture& n)
   obj["Mode"] = n.modeName;
   obj["ModeInfo"] = n.mode;
   obj["Address"] = n.address;
-  obj["Channels"] = n.controls;
+  if(!n.controls.empty())
+    obj["Channels"] = n.controls;
+  else if(n.led)
+    obj["LED"] = n.led;
+  obj["Universe"] = n.universe;
   stream.EndObject();
 }
 
@@ -184,20 +292,29 @@ void JSONWriter::write(Protocols::Artnet::Fixture& n)
   if(auto mi = obj.tryGet("ModeInfo"))
     n.mode <<= *mi;
   n.address <<= obj["Address"];
-  n.controls <<= obj["Channels"];
+  if(auto u = obj.tryGet("Universe"))
+    n.universe = u->toInt();
+  else
+    n.universe = -1;
+  if(auto ctls = obj.tryGet("Channels"))
+    n.controls <<= *ctls;
+  else if(auto led = obj.tryGet("LED"))
+    n.led <<= *led;
 }
 
 template <>
 void DataStreamReader::read(const Protocols::ArtnetSpecificSettings& n)
 {
-  m_stream << n.fixtures << n.host << n.rate << n.universe << n.transport << n.mode;
+  m_stream << n.fixtures << n.host << n.rate << n.start_universe << n.universe_count
+           << n.channels_per_universe << n.multicast << n.transport << n.mode;
   insertDelimiter();
 }
 
 template <>
 void DataStreamWriter::write(Protocols::ArtnetSpecificSettings& n)
 {
-  m_stream >> n.fixtures >> n.host >> n.rate >> n.universe >> n.transport >> n.mode;
+  m_stream >> n.fixtures >> n.host >> n.rate >> n.start_universe >> n.universe_count
+      >> n.channels_per_universe >> n.multicast >> n.transport >> n.mode;
   checkDelimiter();
 }
 
@@ -207,7 +324,11 @@ void JSONReader::read(const Protocols::ArtnetSpecificSettings& n)
   obj["Fixtures"] = n.fixtures;
   obj["Host"] = n.host;
   obj["Rate"] = n.rate;
-  obj["Universe"] = n.universe;
+  obj["Universe"] = n.start_universe;
+  obj["UniverseCount"] = n.universe_count;
+  obj["ChannelsPerUniverse"] = n.channels_per_universe;
+  if(n.multicast)
+    obj["Multicast"] = n.multicast;
   obj["Transport"] = n.transport;
   obj["Mode"] = n.mode;
 }
@@ -221,10 +342,23 @@ void JSONWriter::write(Protocols::ArtnetSpecificSettings& n)
     n.host = QString::fromStdString(u->toStdString());
   n.rate <<= obj["Rate"];
   if(auto u = obj.tryGet("Universe"))
-    n.universe = u->toInt();
+    n.start_universe = u->toInt();
+  if(auto u = obj.tryGet("UniverseCount"))
+    n.universe_count = u->toInt();
+  if(auto u = obj.tryGet("ChannelsPerUniverse"))
+    n.channels_per_universe = u->toInt();
+  if(auto u = obj.tryGet("Multicast"))
+    n.multicast = u->toBool();
   if(auto u = obj.tryGet("Transport"))
     n.transport = (decltype(n.transport))u->toInt();
   if(auto u = obj.tryGet("Mode"))
     n.mode = (decltype(n.mode))u->toInt();
+
+  // score 3.4.2: fixtures can be in multiple universes
+  for(auto& fix : n.fixtures)
+  {
+    if(fix.universe == -1)
+      fix.universe = n.start_universe;
+  }
 }
 #endif
