@@ -141,6 +141,9 @@ public:
   void showRulers(bool);
   void ready() override;
 
+  void zoom(double zx, double zy);
+  void scroll(double dx, double dy);
+
 public:
   void elementsScaleChanged(double arg_1) W_SIGNAL(elementsScaleChanged, arg_1);
   void setLargeView() W_SIGNAL(setLargeView);
