@@ -22,10 +22,10 @@ public:
   Steinberg::uint32 addRef() override { return 1; }
   Steinberg::uint32 release() override { return 1; }
 
-  QDialog& w;
+  QDialog* w;
   WindowContainer wc;
   PlugFrame(QDialog& w, WindowContainer& wc)
-      : w{w}
+      : w{&w}
       , wc{wc}
   {
   }
@@ -33,7 +33,7 @@ public:
   Steinberg::tresult
   resizeView(Steinberg::IPlugView* view, Steinberg::ViewRect* newSize) override
   {
-    wc.setSizeFromVst(*view, *newSize, w);
+    wc.setSizeFromVst(*view, *newSize, *w);
     return Steinberg::kResultOk;
   }
 };
@@ -52,10 +52,10 @@ public:
   Steinberg::uint32 addRef() override { return 1; }
   Steinberg::uint32 release() override { return 1; }
 
-  QDialog& w;
+  QDialog* w;
   WindowContainer wc;
   PlugFrame(QDialog& w, WindowContainer& wc)
-      : w{w}
+      : w{&w}
       , wc{wc}
   {
   }
@@ -63,7 +63,7 @@ public:
   Steinberg::tresult
   resizeView(Steinberg::IPlugView* view, Steinberg::ViewRect* newSize) override
   {
-    wc.setSizeFromVst(*view, *newSize, w);
+    wc.setSizeFromVst(*view, *newSize, *w);
     return Steinberg::kResultOk;
   }
 };
