@@ -38,13 +38,6 @@ void throw_exception(std::exception const& e, boost::source_location const& loc)
 }
 #endif
 
-// clang-format off
-#include <score/tools/InvisibleWindow.hpp>
-#undef OK
-#undef NO
-#undef Status
-// clang-format on
-
 intptr_t vst_host_callback(
     AEffect* effect, int32_t opcode, int32_t index, intptr_t value, void* ptr, float opt)
 {
@@ -247,17 +240,19 @@ struct app
   }
 };
 
+void init_invisible_window();
 int main(int argc, char** argv)
 {
   if(argc <= 1)
     return 1;
 
+  init_invisible_window();
+
   int id = 0;
   if(argc > 2)
     id = std::atoi(argv[2]);
 
   app a;
-  invisible_window w;
 
   boost::asio::post(a.ctx, [&] { a.load(argv[1], id); });
 
@@ -273,3 +268,36 @@ int main(int argc, char** argv)
   a.ctx.run();
   return a.json_ret.empty() ? 1 : 0;
 }
+
+#if defined(_MSC_VER)
+#include <ShlObj.h>
+#include <shellapi.h>
+#include <stdio.h>
+#include <windows.h>
+static inline char* wideToMulti(int codePage, const wchar_t* aw)
+{
+  const int required = WideCharToMultiByte(codePage, 0, aw, -1, NULL, 0, NULL, NULL);
+  char* result = new char[required];
+  WideCharToMultiByte(codePage, 0, aw, -1, result, required, NULL, NULL);
+  return result;
+}
+
+extern "C" int APIENTRY
+WinMain(HINSTANCE, HINSTANCE, LPSTR /*cmdParamarg*/, int /* cmdShow */)
+{
+  int argc;
+  wchar_t** argvW = CommandLineToArgvW(GetCommandLineW(), &argc);
+  if(!argvW)
+    return -1;
+  char** argv = new char*[argc + 1];
+  for(int i = 0; i < argc; ++i)
+    argv[i] = wideToMulti(CP_ACP, argvW[i]);
+  argv[argc] = nullptr;
+  LocalFree(argvW);
+  const int exitCode = main(argc, argv);
+  for(int i = 0; i < argc && argv[i]; ++i)
+    delete[] argv[i];
+  delete[] argv;
+  return exitCode;
+}
+#endif
